# UI/UX Feedback

**ID:** Feedback-20260129-165156
**URL:** idea://003. Feature-Toolbox Design/mockups/stage-toolbox-modal-v2.html
**Date:** 2026-01-29 16:52:16

## Selected Elements

- `{'selector': 'div.modal-title', 'parents': ['div#modalOverlay', 'div.modal', 'div.modal-header']}`

## Feedback

make the size bigger as 40px

## Screenshot

![Screenshot](./page-screenshot.png)
